==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/81/812545b7a12844a6280258960ef86d57.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/cards/assets/logo_black.png */
class __TwigTemplate_c0b4f08ed48b67189d290b4e093d4910 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000,\000\000\000N\000\000\0006+\000\000\000tEXtSoftware\000Adobe ImageReadyqe<\000\000IDATx]u62\000762\tNtw'4\t\$O gW-\000~}S^8݁\000&\"
TG?g=QZ\000\000&ȩ#+MRl\000IRGiIvGEj\000\000\000V袧[\$uN6GQ(\000\000.b9(K\000\000\"#⺆y\000\000:i\$REԸ\000`!f&3zmI\000ƑXrm!E!ut\\(\000\\Wi\000
\000@
L\000
\000\000崆f(_q6@Iՙuuu3,TKfﺱF'kJ{z?=jԈ\"rj,彾!|'vt:rZzư/+-;0bz?dI~kYk>&~_e] W׎N3̀ÀH5qPцJqDe\000vC&*54M.)FU!CH3Nuf)/-]:{IjVuQU &/7iAX,B[BVIkr&\tU'KQ\$6uza;mNYc`:Y+JgmO2to{:Ɇ[0E׈Rl.ZWD\"mDrQ:AYAۅԮ.i@)7dlS&(;x7cD\"Dl\tiЁTj1\"a||wR9JXR'J{\000&EDB:XNZ*aQq|nj<>]}@MZ(\$ͭ.ibSHe㑌(u87JUل4b,U&@;n=ٓBƹhe
\t@M{!!@G. &)\tu/>bv#|j
sN5a\$96@;VI!
|Wڱ'+t3ÿoc/'s|9MtayZuֆVɤ{H}4}#-H֖2CDa2Dیt1:~_#\000%JDzj`N5\000uQ@xt+&)2\000\$3*t\000r!,\000
HHGu!\000J0^2
\000N0A'[%|oYc. Q*4贶8-^6_4nK)QOaG!gnSgm6VǞIq
RB7FںS\t7rr߄VF;M}<vU(cb1=g;ua\t1=@;y'E7UB؉r
tǙ>ܗݬ}Ԇ6n>lMy׆)j2<t(a~\t]b{|oK1ǁqLNB_Z34~?p3n~ʭ5MAպJĹZ\tvqj̥LX5o9SåsɩᯪekjD۹C1-ầ)pd|cAZ2q[+.-Sudp
R>ɱ]\"b䴲|r}ۺ%*ػLV*]!l
NnkoQM{ep_<܎ֺ
8̈́ysڤ7<N,'?W*saHZd0q.\000yr\tq\"5sB\\zC
,
 -IgK!g&*-LZ&'H+\tzWr6P{Cʈc\tk>sZf',7 m<^}±r0T0\$a<׀j=m\"fbވ{CfI[A(K;Q|NDYRdG@7ɹv)!=eV&]Nޜu5׺\\\000\000-DZ\000K/+\000@Z +\000\000@\000`t5^,E\000F/qz\"\000\000#ީ7\000xÙ1\000(jfm\000a\000\000Υ)J\000\000ʏloL\000\000T:%uuǻUKԨ\000PL\"<ґוx풲mP\000\000+\000LKU\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/cards/assets/logo_black.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/cards/assets/logo_black.png", "/var/www/html/mauticGIT-Test/themes/cards/assets/logo_black.png");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/81/812545b7a12844a6280258960ef86d57.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/cards/assets/logo_black.png */
class __TwigTemplate_c0b4f08ed48b67189d290b4e093d4910 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000,\000\000\000N\000\000\0006+\000\000\000tEXtSoftware\000Adobe ImageReadyqe<\000\000IDATx]u62\000762\tNtw'4\t\$O gW-\000~}S^8݁\000&\"
TG?g=QZ\000\000&ȩ#+MRl\000IRGiIvGEj\000\000\000V袧[\$uN6GQ(\000\000.b9(K\000\000\"#⺆y\000\000:i\$REԸ\000`!f&3zmI\000ƑXrm!E!ut\\(\000\\Wi\000
\000@
L\000
\000\000崆f(_q6@Iՙuuu3,TKfﺱF'kJ{z?=jԈ\"rj,彾!|'vt:rZzư/+-;0bz?dI~kYk>&~_e] W׎N3̀ÀH5qPцJqDe\000vC&*54M.)FU!CH3Nuf)/-]:{IjVuQU &/7iAX,B[BVIkr&\tU'KQ\$6uza;mNYc`:Y+JgmO2to{:Ɇ[0E׈Rl.ZWD\"mDrQ:AYAۅԮ.i@)7dlS&(;x7cD\"Dl\tiЁTj1\"a||wR9JXR'J{\000&EDB:XNZ*aQq|nj<>]}@MZ(\$ͭ.ibSHe㑌(u87JUل4b,U&@;n=ٓBƹhe
\t@M{!!@G. &)\tu/>bv#|j
sN5a\$96@;VI!
|Wڱ'+t3ÿoc/'s|9MtayZuֆVɤ{H}4}#-H֖2CDa2Dیt1:~_#\000%JDzj`N5\000uQ@xt+&)2\000\$3*t\000r!,\000
HHGu!\000J0^2
\000N0A'[%|oYc. Q*4贶8-^6_4nK)QOaG!gnSgm6VǞIq
RB7FںS\t7rr߄VF;M}<vU(cb1=g;ua\t1=@;y'E7UB؉r
tǙ>ܗݬ}Ԇ6n>lMy׆)j2<t(a~\t]b{|oK1ǁqLNB_Z34~?p3n~ʭ5MAպJĹZ\tvqj̥LX5o9SåsɩᯪekjD۹C1-ầ)pd|cAZ2q[+.-Sudp
R>ɱ]\"b䴲|r}ۺ%*ػLV*]!l
NnkoQM{ep_<܎ֺ
8̈́ysڤ7<N,'?W*saHZd0q.\000yr\tq\"5sB\\zC
,
 -IgK!g&*-LZ&'H+\tzWr6P{Cʈc\tk>sZf',7 m<^}±r0T0\$a<׀j=m\"fbވ{CfI[A(K;Q|NDYRdG@7ɹv)!=eV&]Nޜu5׺\\\000\000-DZ\000K/+\000@Z +\000\000@\000`t5^,E\000F/qz\"\000\000#ީ7\000xÙ1\000(jfm\000a\000\000Υ)J\000\000ʏloL\000\000T:%uuǻUKԨ\000PL\"<ґוx풲mP\000\000+\000LKU\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/cards/assets/logo_black.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/cards/assets/logo_black.png", "/var/www/html/production-demo/themes/cards/assets/logo_black.png");
    }
}
